@@ -298,7 +298,7 @@ static py::object to_py(FBFR32 *fbfr, FLDLEN32 buflen = 0) {
       case FLD_STRING:
         val.append(
 #if PY_MAJOR_VERSION >= 3
-            py::str(PyUnicode_DecodeLocale(value.get(), "surrogateescape"))
+            py::reinterpret_steal<py::str>(PyUnicode_DecodeLocale(value.get(), "surrogateescape"))
 #else
             py::bytes(value.get(), len - 1)
 #endif
@@ -682,8 +682,10 @@ void PY(TPSVCINFO *svcinfo) {
     auto idata = to_py(xatmibuf(svcinfo));
 
     auto &&func = server.attr(svcinfo->name);
-    auto &&argspec = py::module::import("inspect").attr("getargspec")(func);
-    auto &&args = argspec.attr("args");
+    auto &&code = func.attr("__code__");
+    long argcount = (code.attr("co_argcount") + code.attr("co_kwonlyargcount"))
+                        .cast<py::int_>();
+    auto &&args = code.attr("co_varnames")[py::slice(0, argcount, 1)];
     py::dict kwargs;
     if (args.contains(py::str("name"))) {
       kwargs[py::str("name")] = py::str(svcinfo->name);
@@ -1227,6 +1229,23 @@ PYBIND11_MODULE(tuxedowsc, m) {
       },
       "Maps field name to field identifier", py::arg("name"));
 
+  m.def(
+      "Fboolpr32",
+      [](const char *expression, py::object iop) {
+        std::unique_ptr<char, decltype(&free)> guard(
+            Fboolco32(const_cast<char *>(expression)), &free);
+        if (guard.get() == nullptr) {
+          throw fml32_exception(Ferror32);
+        }
+
+        int fd = iop.attr("fileno")().cast<py::int_>();
+        std::unique_ptr<FILE, decltype(&fclose)> fiop(fdopen(dup(fd), "w"),
+                                                      &fclose);
+        Fboolpr32(guard.get(), fiop.get());
+      },
+      "Print Boolean expression as parsed", py::arg("expression"),
+      py::arg("iop"));
+
   m.def(
       "Fboolev32",
       [](py::object fbfr, const char *expression) {
